# Structures

Structure files describe the internal structure of historical sources and are used by the translator to process and validate source transcriptios. Structure files define what can be registred for each type of source.

